@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: yesod
 version: 1.4.3
-id: yesod-1.4.3-89d663579be8afc78aa2c036ac16a3d8
-key: yesod_L58tBxbDKEVEF9cONihwwl
+id: yesod-1.4.3-f305f1bd0a1c829c425775863de16536
+key: yesod_8fLv5vuSLkyKB8SFVID7Ty
 license: MIT
 maintainer: Michael Snoyman <michael@snoyman.com>
 stability: Stable
@@ -21,9 +21,9 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-1.4.3
 library-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-1.4.3
 data-dir: /usr/share/arm-linux-ghc-7.10.3/yesod-1.4.3
-hs-libraries: HSyesod-1.4.3-L58tBxbDKEVEF9cONihwwl
+hs-libraries: HSyesod-1.4.3-8fLv5vuSLkyKB8SFVID7Ty
 depends:
-    aeson-0.11.1.4-86f3cf1b57353fec7f96aad67f54b36b
+    aeson-0.11.2.0-296caa0c9ed52dbc363a5964bf5cee68
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     blaze-html-0.8.1.1-196db2ddcb827bc04473411dd00dd5eb
     blaze-markup-0.7.0.3-301d79472dd24aabecf5f1be193f6bdb
@@ -36,7 +36,7 @@ depends:
     monad-logger-0.3.18-8d0d3ee0b0c9e28288fbc3f8ad4970cb
     safe-0.3.9-b613242f536083d5bb04920ede356aea
     semigroups-0.18.1-1d5ad88275231b75d5bd2afbb0ecbbe4
-    shakespeare-2.0.8.2-9d634aa5cbfd84967239f7d2ea21fe42
+    shakespeare-2.0.8.2-ff3f7104513a25f68869f5890fce9d82
     streaming-commons-0.1.15.4-088f3eb5ae9c0f8f3bf543f124c940b6
     template-haskell-2.10.0.0-4b92ab565139fd81021b60a162b59eb8
     text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
@@ -44,14 +44,14 @@ depends:
     unix-2.7.1.0-a583968f8d5891c6bf334fddb26b19a6
     unordered-containers-0.2.7.0-d91279dcd5fa13d7f88095dc08e2fda6
     wai-3.2.1-82fcd8afd3d66bf63829f2c0f9ec2308
-    wai-extra-3.0.15.1-805c88586e75ad2629c1f825e3e3174b
+    wai-extra-3.0.15.1-c6073df16d7e87fd6a9bad9219062fb9
     wai-logger-2.2.7-ce523aca7009dcd9edbddd06c7250c99
-    warp-3.2.6-88951d0d70fd1890006e06da62bd7b17
-    yaml-0.8.17.1-0d2269c3661604071b13bd3e036107ab
-    yesod-auth-1.4.13.2-8b814b29f0db7fe2c6087994080e0e8c
-    yesod-core-1.4.20.2-0deed42ce8646909d9e6f7d8cb856025
-    yesod-form-1.4.7.1-6b4f60eedefa751296dea3285755c587
-    yesod-persistent-1.4.0.5-f9c4aef4e19cb23b8351ed6db2610b12
+    warp-3.2.6-545f6ad0a6172bad2df83f7b250d6e47
+    yaml-0.8.17.1-6800246ed3e006b412aea827bb28629d
+    yesod-auth-1.4.13.2-2f6d751a770f6feb3333cee2daf3d7c3
+    yesod-core-1.4.20.2-6a9eccc8751a316631c6c2141cb80eb5
+    yesod-form-1.4.7.1-b562018d9d1dff8952cde9168801b7f7
+    yesod-persistent-1.4.0.5-629d475d7f77e3630b315100b50a92c4
 haddock-interfaces: /usr/share/doc/haskell-yesod/html/yesod.haddock
 haddock-html: /usr/share/doc/haskell-yesod/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
